import React, { useState, useEffect } from 'react';
import { Plus } from 'lucide-react';
import { AdsList } from './AdsList';
import { AdEditor } from './AdEditor';
import { getAds, saveAd, updateAd, deleteAd } from '../../../services/adsService';
import type { Ad } from '../../../services/adsService';

export function AdsManager() {
  const [ads, setAds] = useState<Ad[]>([]);
  const [editingAd, setEditingAd] = useState<Ad | undefined>();
  const [isEditing, setIsEditing] = useState(false);

  useEffect(() => {
    setAds(getAds());
  }, []);

  const handleSave = (adData: Omit<Ad, 'id' | 'createdAt' | 'updatedAt'>) => {
    if (editingAd) {
      const updated = updateAd(editingAd.id, adData);
      setAds(ads.map(a => a.id === updated.id ? updated : a));
    } else {
      const newAd = saveAd(adData);
      setAds([...ads, newAd]);
    }
    setIsEditing(false);
    setEditingAd(undefined);
  };

  const handleDelete = (id: string) => {
    if (window.confirm('Are you sure you want to delete this ad?')) {
      deleteAd(id);
      setAds(ads.filter(a => a.id !== id));
    }
  };

  return (
    <div className="space-y-6">
      <div className="flex justify-between items-center">
        <h2 className="text-lg font-medium text-gray-900">Advertisements</h2>
        {!isEditing && (
          <button
            onClick={() => setIsEditing(true)}
            className="flex items-center px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-blue-600 hover:bg-blue-700"
          >
            <Plus className="h-4 w-4 mr-2" />
            Add Ad
          </button>
        )}
      </div>

      {isEditing ? (
        <AdEditor
          ad={editingAd}
          onSave={handleSave}
          onCancel={() => {
            setIsEditing(false);
            setEditingAd(undefined);
          }}
        />
      ) : (
        <AdsList
          ads={ads}
          onEdit={(ad) => {
            setEditingAd(ad);
            setIsEditing(true);
          }}
          onDelete={handleDelete}
        />
      )}
    </div>
  );
}