import React, { useState, useEffect } from 'react';
import { Plus } from 'lucide-react';
import { PagesList } from './PagesList';
import { PageEditor } from './PageEditor';
import { getPages, savePage, updatePage, deletePage } from '../../../services/pagesService';
import type { CustomPage } from '../../../services/pagesService';

export function PagesManager() {
  const [pages, setPages] = useState<CustomPage[]>([]);
  const [editingPage, setEditingPage] = useState<CustomPage | undefined>();
  const [isEditing, setIsEditing] = useState(false);

  useEffect(() => {
    setPages(getPages());
  }, []);

  const handleSave = (pageData: Omit<CustomPage, 'id' | 'createdAt' | 'updatedAt'>) => {
    if (editingPage) {
      const updated = updatePage(editingPage.id, pageData);
      setPages(pages.map(p => p.id === updated.id ? updated : p));
    } else {
      const newPage = savePage(pageData);
      setPages([...pages, newPage]);
    }
    setIsEditing(false);
    setEditingPage(undefined);
  };

  const handleDelete = (id: string) => {
    if (window.confirm('Are you sure you want to delete this page?')) {
      deletePage(id);
      setPages(pages.filter(p => p.id !== id));
    }
  };

  return (
    <div className="space-y-6">
      <div className="flex justify-between items-center">
        <h2 className="text-lg font-medium text-gray-900">Custom Pages</h2>
        {!isEditing && (
          <button
            onClick={() => setIsEditing(true)}
            className="flex items-center px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-blue-600 hover:bg-blue-700"
          >
            <Plus className="h-4 w-4 mr-2" />
            Add Page
          </button>
        )}
      </div>

      {isEditing ? (
        <PageEditor
          page={editingPage}
          onSave={handleSave}
          onCancel={() => {
            setIsEditing(false);
            setEditingPage(undefined);
          }}
        />
      ) : (
        <PagesList
          pages={pages}
          onEdit={(page) => {
            setEditingPage(page);
            setIsEditing(true);
          }}
          onDelete={handleDelete}
        />
      )}
    </div>
  );
}