import { useState, useEffect } from 'react';
import { performSearch } from '../services/searchService';
import type { SearchResult } from '../services/searchService';
import { updateQueryParam, getQueryParam } from '../utils/urlUtils';

export function useSearch() {
  const [searchResults, setSearchResults] = useState<SearchResult[]>([]);
  const [totalResults, setTotalResults] = useState(0);
  const [currentPage, setCurrentPage] = useState(1);
  const [currentQuery, setCurrentQuery] = useState('');
  const [activeFilter, setActiveFilter] = useState('All');
  const [hasSearched, setHasSearched] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  // Initialize from URL query parameter
  useEffect(() => {
    const queryParam = getQueryParam('q');
    if (queryParam) {
      handleSearch(queryParam);
    }
  }, []);

  const handleSearch = async (query: string, page: number = 1) => {
    setIsLoading(true);
    setHasSearched(true);
    setCurrentQuery(query);
    
    // Update URL query parameter
    updateQueryParam('q', query);
    
    try {
      const response = await performSearch(query, page);
      setSearchResults(response.items || []);
      setTotalResults(parseInt(response.searchInformation.totalResults, 10));
      setCurrentPage(page);
    } catch (error) {
      console.error('Search failed:', error);
      setSearchResults([]);
      setTotalResults(0);
    } finally {
      setIsLoading(false);
    }
  };

  const handlePageChange = (page: number) => {
    handleSearch(currentQuery, page);
  };

  const handleFilterChange = (filter: string) => {
    setActiveFilter(filter);
  };

  return {
    searchResults,
    totalResults,
    currentPage,
    currentQuery,
    activeFilter,
    hasSearched,
    isLoading,
    handleSearch,
    handlePageChange,
    handleFilterChange
  };
}