import { v4 as uuidv4 } from 'uuid';

export interface Ad {
  id: string;
  title: string;
  description: string;
  displayUrl: string;
  targetUrl: string;
  keywords: string[];
  isActive: boolean;
  createdAt: string;
  updatedAt: string;
}

export function getAds(): Ad[] {
  const ads = localStorage.getItem('ads');
  return ads ? JSON.parse(ads) : [
    // Demo ad
    {
      id: uuidv4(),
      title: 'Demo Advertisement',
      description: 'This is a demo ad that appears when searching for "demo"',
      displayUrl: 'example.com',
      targetUrl: 'https://example.com',
      keywords: ['demo'],
      isActive: true,
      createdAt: new Date().toISOString(),
      updatedAt: new Date().toISOString()
    }
  ];
}

export function saveAd(ad: Omit<Ad, 'id' | 'createdAt' | 'updatedAt'>): Ad {
  const ads = getAds();
  const newAd: Ad = {
    ...ad,
    id: uuidv4(),
    createdAt: new Date().toISOString(),
    updatedAt: new Date().toISOString(),
  };
  
  ads.push(newAd);
  localStorage.setItem('ads', JSON.stringify(ads));
  return newAd;
}

export function updateAd(id: string, updates: Partial<Ad>): Ad {
  const ads = getAds();
  const index = ads.findIndex(ad => ad.id === id);
  
  if (index === -1) throw new Error('Ad not found');
  
  const updatedAd = {
    ...ads[index],
    ...updates,
    updatedAt: new Date().toISOString(),
  };
  
  ads[index] = updatedAd;
  localStorage.setItem('ads', JSON.stringify(ads));
  return updatedAd;
}

export function deleteAd(id: string): void {
  const ads = getAds();
  const filteredAds = ads.filter(ad => ad.id !== id);
  localStorage.setItem('ads', JSON.stringify(filteredAds));
}

export function getAdsByKeyword(keyword: string): Ad[] {
  if (!keyword) return [];
  
  const ads = getAds();
  return ads.filter(ad => 
    ad.isActive && 
    ad.keywords.some(k => k.toLowerCase() === keyword.toLowerCase())
  );
}